.. NGLView documentation master file, created by
   sphinx-quickstart on Thu May  5 10:58:11 2016.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.


Scripts
=======

.. container:: custom-index
    
    .. raw:: html
    
        <script type="text/javascript" src='_static/cindex.js'></script>

Contents:

.. toctree::
   :maxdepth: 2

.. automodule:: scripts
    :members:
    :undoc-members:
    :show-inheritance:


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
